reset
set terminal pdfcairo enhanced font 'Serif,13' size 3.0,3.0
set encoding utf8
set palette @MATLAB

unset colorbox
set size ratio -1

set grid

set mxtics 5
set mytics 5

set rmargin screen 0.97
set lmargin screen 0.16
set tmargin screen 1.0
set bmargin screen 0.15

slw = 0.8
llw = 1.1
sps = 0.3

tlw = 1.1

set style line 11 lw tlw lc rgb "#0080FF" dt 1
set style line 22 lw tlw lc rgb "#66CC66" dt 4
set style line 33 lw tlw lc rgb "#FF8000" dt 2


set xtics 0.2 offset screen 0.0,0.004
set ytics 0.2

set xrange[-1:0.1]
set yrange[-1:0.1]
set xlabel 'm_1' offset screen 0.0, 0.011
set ylabel 'm_2' offset screen 0.03

set xtics format "%2.1f"
set ytics format "%2.1f"

set key at screen 0.7,0.94 font ",9" spacing 0.9 Right spacing 1 samplen 4

set output "jaikkin_m1m2.pdf"

plot 'jaikkin_st1.dat' u 2:3:7  notit w l ls 11, '' u 5:6:7 notit w l ls 11,\
     'jaikkin_st2.dat' u 2:3:7  notit w l ls 22, '' u 5:6:7 notit w l ls 22,\
     'jaikkin_st3.dat' u 2:3:13 notit w l ls 33, '' u 5:6:13 notit w l ls 33, '' u 8:9:13 notit w l ls 33,\
     -10 tit 'Elastic (P =         0..11736)' w l ls 11 lw 2,\
     -10 tit 'Hinge (P = 11736..18980)' w l ls 22 lw 2,\
     -10 tit 'Elastic-Plastic (P = 11736..29925)' w l ls 33 lw 2,\
     '' u 11:12 tit "η" w p pt 2 ps 0.7 lc -1




##############################################
##############################################
##############################################
##############################################
##############################################
##############################################
##############################################
##############################################
##############################################


reset
set terminal pdfcairo enhanced font 'Serif,13' size 4.5,7.1
set encoding utf8
set palette @MATLAB
set grid back
set mxtics 5
set mytics 5
unset colorbox


set rmargin screen 0.97
set lmargin screen 0.15
set tmargin screen 0.99
set bmargin screen 0.70

slw = 0.8
llw = 1.1
sps = 0.3

set style line 1 lw llw ps sps lc palette


set output 'jaikkin_m1.pdf'
set multiplot


set ytics 0.2

set xrange[0.0:1.0]
set yrange[-1.0:0.1]
set xlabel ' '
set ylabel 'm_1'
set xtics format ''
set ytics format "%2.1f"
set key bottom right font ",11" spacing 0.9 Right

set label 'Stage I' at 0.02,-0.1 font ",16"
plot 'jaikkin_st1.dat'\
   ind 1 u 1:2:7 ev 3 tit 'P = 1304' w p ls 1 pt 1, '' ind 1 u 1:2:7 notit w l ls 1, '' ind 1 u 4:5:7 ev 3 notit w linesp ls 1 pt 1,\
'' ind 2 u 1:2:7 ev 3 tit '    2608' w p ls 1 pt 2, '' ind 2 u 1:2:7 notit w l ls 1, '' ind 2 u 4:5:7 ev 3 notit w linesp ls 1 pt 2,\
'' ind 3 u 1:2:7 ev 3 tit '    3912' w p ls 1 pt 3, '' ind 3 u 1:2:7 notit w l ls 1, '' ind 3 u 4:5:7 ev 3 notit w linesp ls 1 pt 3,\
'' ind 4 u 1:2:7 ev 3 tit '    5216' w p ls 1 pt 4, '' ind 4 u 1:2:7 notit w l ls 1, '' ind 4 u 4:5:7 ev 3 notit w linesp ls 1 pt 4,\
'' ind 5 u 1:2:7 ev 3 tit '    6520' w p ls 1 pt 5, '' ind 5 u 1:2:7 notit w l ls 1, '' ind 5 u 4:5:7 ev 3 notit w linesp ls 1 pt 5,\
'' ind 6 u 1:2:7 ev 3 tit '    7824' w p ls 1 pt 6, '' ind 6 u 1:2:7 notit w l ls 1, '' ind 6 u 4:5:7 ev 3 notit w linesp ls 1 pt 6,\
'' ind 7 u 1:2:7 ev 3 tit '    9128' w p ls 1 pt 5, '' ind 7 u 1:2:7 notit w l ls 1, '' ind 7 u 4:5:7 ev 3 notit w linesp ls 1 pt 5,\
'' ind 8 u 1:2:7 ev 3 tit '   10432' w p ls 1 pt 6, '' ind 8 u 1:2:7 notit w l ls 1, '' ind 8 u 4:5:7 ev 3 notit w linesp ls 1 pt 6,\
'' ind 9 u 1:2:7 ev 3 tit '   11736' w p ls 1 pt 7, '' ind 9 u 1:2:7 notit w l ls 1, '' ind 9 u 4:5:7 ev 3 notit w linesp ls 1 pt 7
unset label


set tmargin screen 0.67
set bmargin screen 0.38

set label 'Stage II' at 0.015,-0.1 font ",16"
plot 'jaikkin_st2.dat'\
   ind 0 u 1:2:7 ev 3 tit 'P = 13040' w p ls 1 pt 1, '' ind 0 u 1:2:7 notit w l ls 1, '' ind 0 u 4:5:7 ev 3 notit w linesp ls 1 pt 1,\
'' ind 1 u 1:2:7 ev 3 tit '    13700' w p ls 1 pt 2, '' ind 1 u 1:2:7 notit w l ls 1, '' ind 1 u 4:5:7 ev 3 notit w linesp ls 1 pt 2,\
'' ind 2 u 1:2:7 ev 3 tit '    14360' w p ls 1 pt 3, '' ind 2 u 1:2:7 notit w l ls 1, '' ind 2 u 4:5:7 ev 3 notit w linesp ls 1 pt 3,\
'' ind 3 u 1:2:7 ev 3 tit '    15020' w p ls 1 pt 4, '' ind 3 u 1:2:7 notit w l ls 1, '' ind 3 u 4:5:7 ev 3 notit w linesp ls 1 pt 4,\
'' ind 4 u 1:2:7 ev 3 tit '    15680' w p ls 1 pt 5, '' ind 4 u 1:2:7 notit w l ls 1, '' ind 4 u 4:5:7 ev 3 notit w linesp ls 1 pt 5,\
'' ind 5 u 1:2:7 ev 3 tit '    16340' w p ls 1 pt 6, '' ind 5 u 1:2:7 notit w l ls 1, '' ind 5 u 4:5:7 ev 3 notit w linesp ls 1 pt 6,\
'' ind 6 u 1:2:7 ev 3 tit '    17000' w p ls 1 pt 5, '' ind 6 u 1:2:7 notit w l ls 1, '' ind 6 u 4:5:7 ev 3 notit w linesp ls 1 pt 5,\
'' ind 7 u 1:2:7 ev 3 tit '    17660' w p ls 1 pt 6, '' ind 7 u 1:2:7 notit w l ls 1, '' ind 7 u 4:5:7 ev 3 notit w linesp ls 1 pt 6,\
'' ind 8 u 1:2:7 ev 3 tit '    18320' w p ls 1 pt 7, '' ind 8 u 1:2:7 notit w l ls 1, '' ind 8 u 4:5:7 ev 3 notit w linesp ls 1 pt 7,\
'' ind 9 u 1:2:7 ev 3 tit '    18980' w p ls 1 pt 8, '' ind 9 u 1:2:7 notit w l ls 1, '' ind 9 u 4:5:7 ev 3 notit w linesp ls 1 pt 8
unset label

set tmargin screen 0.35
set bmargin screen 0.06

set xlabel 'r' offset screen 0,0.0
set xtics format "%2.1f"

set label 'Stage III' at 0.01,-0.1 font ",16"
plot 'jaikkin_st3.dat'\
   ind 0 u 1:2:13 ev 3 tit 'P = 19640' w p ls 1 pt 1, '' ind 0 u 1:2:13 notit w l ls 1, '' ind 0 u 4:5:13 ev 5 notit w linesp ls 1 pt 1, '' ind 0 u 7:8:13 ev 3 notit w linesp ls 1 pt 1,\
'' ind 1 u 1:2:13 ev 3 tit '    20640' w p ls 1 pt 2, '' ind 1 u 1:2:13 notit w l ls 1, '' ind 1 u 4:5:13 ev 5 notit w linesp ls 1 pt 2, '' ind 1 u 7:8:13 ev 3 notit w linesp ls 1 pt 2,\
'' ind 2 u 1:2:13 ev 3 tit '    21640' w p ls 1 pt 3, '' ind 2 u 1:2:13 notit w l ls 1, '' ind 2 u 4:5:13 ev 5 notit w linesp ls 1 pt 3, '' ind 2 u 7:8:13 ev 3 notit w linesp ls 1 pt 3,\
'' ind 3 u 1:2:13 ev 3 tit '    22640' w p ls 1 pt 4, '' ind 3 u 1:2:13 notit w l ls 1, '' ind 3 u 4:5:13 ev 5 notit w linesp ls 1 pt 4, '' ind 3 u 7:8:13 ev 3 notit w linesp ls 1 pt 4,\
'' ind 4 u 1:2:13 ev 3 tit '    23640' w p ls 1 pt 5, '' ind 4 u 1:2:13 notit w l ls 1, '' ind 4 u 4:5:13 ev 5 notit w linesp ls 1 pt 5, '' ind 4 u 7:8:13 ev 3 notit w linesp ls 1 pt 5,\
'' ind 5 u 1:2:13 ev 3 tit '    24640' w p ls 1 pt 6, '' ind 5 u 1:2:13 notit w l ls 1, '' ind 5 u 4:5:13 ev 5 notit w linesp ls 1 pt 6, '' ind 5 u 7:8:13 ev 3 notit w linesp ls 1 pt 6,\
'' ind 6 u 1:2:13 ev 3 tit '    25640' w p ls 1 pt 5, '' ind 6 u 1:2:13 notit w l ls 1, '' ind 6 u 4:5:13 ev 5 notit w linesp ls 1 pt 5, '' ind 6 u 7:8:13 ev 3 notit w linesp ls 1 pt 5,\
'' ind 7 u 1:2:13 ev 3 tit '    26640' w p ls 1 pt 6, '' ind 7 u 1:2:13 notit w l ls 1, '' ind 7 u 4:5:13 ev 5 notit w linesp ls 1 pt 6, '' ind 7 u 7:8:13 ev 3 notit w linesp ls 1 pt 6,\
'' ind 8 u 1:2:13 ev 3 tit '    27640' w p ls 1 pt 7, '' ind 8 u 1:2:13 notit w l ls 1, '' ind 8 u 4:5:13 ev 5 notit w linesp ls 1 pt 7, '' ind 8 u 7:8:13 ev 3 notit w linesp ls 1 pt 7,\
'' ind 9 u 1:2:13 ev 3 tit '    29640' w p ls 1 pt 8, '' ind 9 u 1:2:13 notit w l ls 1, '' ind 9 u 4:5:13 ev 5 notit w linesp ls 1 pt 8, '' ind 9 u 7:8:13 ev 3 notit w linesp ls 1 pt 8,\
'' ind 10 u 1:2:13 ev 3 tit '   29640' w p ls 1 pt 3, '' ind 10 u 1:2:13 notit w l ls 1, '' ind 10 u 4:5:13 ev 5 notit w linesp ls 1 pt 3, '' ind 10 u 7:8:13 ev 3 notit w linesp ls 1 pt 3,\
'' u 10:11 tit "η" w p pt 2 ps 0.7 lc -1
unset multiplot



##############################################
##############################################
##############################################
##############################################
##############################################
##############################################
##############################################
##############################################
##############################################


reset
set terminal pdfcairo enhanced font 'Serif,13' size 4.5,7.1
set encoding utf8
set palette @MATLAB
set grid back
set mxtics 5
set mytics 5
unset colorbox


set rmargin screen 0.97
set lmargin screen 0.15
set tmargin screen 0.99
set bmargin screen 0.70

slw = 0.8
llw = 1.1
sps = 0.3

set style line 1 lw llw ps sps lc palette


set output 'jaikkin_m2.pdf'
set multiplot


set ytics 0.2

set xrange[0.0:1.0]
set yrange[-1.0:0.1]
set xlabel ' '
set ylabel 'm_2'
set xtics format ''
set ytics format "%2.1f"
set key bottom right font ",11" spacing 0.9 Right

set label 'Stage I' at 0.02,-0.1 font ",16"
plot 'jaikkin_st1.dat'\
   ind 1 u 1:3:7 ev 3 tit 'P = 1304' w p ls 1 pt 1, '' ind 1 u 1:3:7 notit w l ls 1, '' ind 1 u 4:6:7 ev 3 notit w linesp ls 1 pt 1,\
'' ind 2 u 1:3:7 ev 3 tit '    2608' w p ls 1 pt 2, '' ind 2 u 1:3:7 notit w l ls 1, '' ind 2 u 4:6:7 ev 3 notit w linesp ls 1 pt 2,\
'' ind 3 u 1:3:7 ev 3 tit '    3912' w p ls 1 pt 3, '' ind 3 u 1:3:7 notit w l ls 1, '' ind 3 u 4:6:7 ev 3 notit w linesp ls 1 pt 3,\
'' ind 4 u 1:3:7 ev 3 tit '    5216' w p ls 1 pt 4, '' ind 4 u 1:3:7 notit w l ls 1, '' ind 4 u 4:6:7 ev 3 notit w linesp ls 1 pt 4,\
'' ind 5 u 1:3:7 ev 3 tit '    6520' w p ls 1 pt 5, '' ind 5 u 1:3:7 notit w l ls 1, '' ind 5 u 4:6:7 ev 3 notit w linesp ls 1 pt 5,\
'' ind 6 u 1:3:7 ev 3 tit '    7824' w p ls 1 pt 6, '' ind 6 u 1:3:7 notit w l ls 1, '' ind 6 u 4:6:7 ev 3 notit w linesp ls 1 pt 6,\
'' ind 7 u 1:3:7 ev 3 tit '    9128' w p ls 1 pt 5, '' ind 7 u 1:3:7 notit w l ls 1, '' ind 7 u 4:6:7 ev 3 notit w linesp ls 1 pt 5,\
'' ind 8 u 1:3:7 ev 3 tit '   10432' w p ls 1 pt 6, '' ind 8 u 1:3:7 notit w l ls 1, '' ind 8 u 4:6:7 ev 3 notit w linesp ls 1 pt 6,\
'' ind 9 u 1:3:7 ev 3 tit '   11736' w p ls 1 pt 7, '' ind 9 u 1:3:7 notit w l ls 1, '' ind 9 u 4:6:7 ev 3 notit w linesp ls 1 pt 7
unset label


set tmargin screen 0.67
set bmargin screen 0.38

set label 'Stage II' at 0.015,-0.1 font ",16"
plot 'jaikkin_st2.dat'\
   ind 0 u 1:3:7 ev 3 tit 'P = 13040' w p ls 1 pt 1, '' ind 0 u 1:3:7 notit w l ls 1, '' ind 0 u 4:6:7 ev 3 notit w linesp ls 1 pt 1,\
'' ind 1 u 1:3:7 ev 3 tit '    13700' w p ls 1 pt 2, '' ind 1 u 1:3:7 notit w l ls 1, '' ind 1 u 4:6:7 ev 3 notit w linesp ls 1 pt 2,\
'' ind 2 u 1:3:7 ev 3 tit '    14360' w p ls 1 pt 3, '' ind 2 u 1:3:7 notit w l ls 1, '' ind 2 u 4:6:7 ev 3 notit w linesp ls 1 pt 3,\
'' ind 3 u 1:3:7 ev 3 tit '    15020' w p ls 1 pt 4, '' ind 3 u 1:3:7 notit w l ls 1, '' ind 3 u 4:6:7 ev 3 notit w linesp ls 1 pt 4,\
'' ind 4 u 1:3:7 ev 3 tit '    15680' w p ls 1 pt 5, '' ind 4 u 1:3:7 notit w l ls 1, '' ind 4 u 4:6:7 ev 3 notit w linesp ls 1 pt 5,\
'' ind 5 u 1:3:7 ev 3 tit '    16340' w p ls 1 pt 6, '' ind 5 u 1:3:7 notit w l ls 1, '' ind 5 u 4:6:7 ev 3 notit w linesp ls 1 pt 6,\
'' ind 6 u 1:3:7 ev 3 tit '    17000' w p ls 1 pt 5, '' ind 6 u 1:3:7 notit w l ls 1, '' ind 6 u 4:6:7 ev 3 notit w linesp ls 1 pt 5,\
'' ind 7 u 1:3:7 ev 3 tit '    17660' w p ls 1 pt 6, '' ind 7 u 1:3:7 notit w l ls 1, '' ind 7 u 4:6:7 ev 3 notit w linesp ls 1 pt 6,\
'' ind 8 u 1:3:7 ev 3 tit '    18320' w p ls 1 pt 7, '' ind 8 u 1:3:7 notit w l ls 1, '' ind 8 u 4:6:7 ev 3 notit w linesp ls 1 pt 7,\
'' ind 9 u 1:3:7 ev 3 tit '    18980' w p ls 1 pt 8, '' ind 9 u 1:3:7 notit w l ls 1, '' ind 9 u 4:6:7 ev 3 notit w linesp ls 1 pt 8
unset label

set tmargin screen 0.35
set bmargin screen 0.06

set xlabel 'r' offset screen 0,0.0
set xtics format "%2.1f"

set key at screen 0.38,0.09 font ",11" spacing 0.9 Right

set label 'Stage III' at 0.01,-0.1 font ",16"
plot 'jaikkin_st3.dat'\
   ind 0 u 1:3:13 ev 3 tit 'P = 19640' w p ls 1 pt 1, '' ind 0 u 1:3:13 notit w l ls 1, '' ind 0 u 4:6:13 ev 5 notit w linesp ls 1 pt 1, '' ind 0 u 7:9:13 ev 3 notit w linesp ls 1 pt 1,\
'' ind 1 u 1:3:13 ev 3 tit '    20640' w p ls 1 pt 2, '' ind 1 u 1:3:13 notit w l ls 1, '' ind 1 u 4:6:13 ev 5 notit w linesp ls 1 pt 2, '' ind 1 u 7:9:13 ev 3 notit w linesp ls 1 pt 2,\
'' ind 2 u 1:3:13 ev 3 tit '    21640' w p ls 1 pt 3, '' ind 2 u 1:3:13 notit w l ls 1, '' ind 2 u 4:6:13 ev 5 notit w linesp ls 1 pt 3, '' ind 2 u 7:9:13 ev 3 notit w linesp ls 1 pt 3,\
'' ind 3 u 1:3:13 ev 3 tit '    22640' w p ls 1 pt 4, '' ind 3 u 1:3:13 notit w l ls 1, '' ind 3 u 4:6:13 ev 5 notit w linesp ls 1 pt 4, '' ind 3 u 7:9:13 ev 3 notit w linesp ls 1 pt 4,\
'' ind 4 u 1:3:13 ev 3 tit '    23640' w p ls 1 pt 5, '' ind 4 u 1:3:13 notit w l ls 1, '' ind 4 u 4:6:13 ev 5 notit w linesp ls 1 pt 5, '' ind 4 u 7:9:13 ev 3 notit w linesp ls 1 pt 5,\
'' ind 5 u 1:3:13 ev 3 tit '    24640' w p ls 1 pt 6, '' ind 5 u 1:3:13 notit w l ls 1, '' ind 5 u 4:6:13 ev 5 notit w linesp ls 1 pt 6, '' ind 5 u 7:9:13 ev 3 notit w linesp ls 1 pt 6,\
'' ind 6 u 1:3:13 ev 3 tit '    25640' w p ls 1 pt 5, '' ind 6 u 1:3:13 notit w l ls 1, '' ind 6 u 4:6:13 ev 5 notit w linesp ls 1 pt 5, '' ind 6 u 7:9:13 ev 3 notit w linesp ls 1 pt 5,\
'' ind 7 u 1:3:13 ev 3 tit '    26640' w p ls 1 pt 6, '' ind 7 u 1:3:13 notit w l ls 1, '' ind 7 u 4:6:13 ev 5 notit w linesp ls 1 pt 6, '' ind 7 u 7:9:13 ev 3 notit w linesp ls 1 pt 6,\
'' ind 8 u 1:3:13 ev 3 tit '    27640' w p ls 1 pt 7, '' ind 8 u 1:3:13 notit w l ls 1, '' ind 8 u 4:6:13 ev 5 notit w linesp ls 1 pt 7, '' ind 8 u 7:9:13 ev 3 notit w linesp ls 1 pt 7,\
'' ind 9 u 1:3:13 ev 3 tit '    29640' w p ls 1 pt 8, '' ind 9 u 1:3:13 notit w l ls 1, '' ind 9 u 4:6:13 ev 5 notit w linesp ls 1 pt 8, '' ind 9 u 7:9:13 ev 3 notit w linesp ls 1 pt 8,\
'' ind 10 u 1:3:13 ev 3 tit '   29640' w p ls 1 pt 3, '' ind 10 u 1:3:13 notit w l ls 1, '' ind 10 u 4:6:13 ev 5 notit w linesp ls 1 pt 3, '' ind 10 u 7:9:13 ev 3 notit w linesp ls 1 pt 3,\
'' u 10:12 tit "η" w p pt 2 ps 0.7 lc -1

unset multiplot


##############################################
##############################################
##############################################
##############################################
##############################################
##############################################
##############################################
##############################################
##############################################


reset
set terminal pdfcairo enhanced font 'Serif,13' size 4.5,7.1
set encoding utf8
set palette @MATLAB
set grid back
set mxtics 5
set mytics 5
unset colorbox


set rmargin screen 0.97
set lmargin screen 0.15
set tmargin screen 0.99
set bmargin screen 0.70

slw = 0.8
llw = 1.1
sps = 0.3

set style line 1 lw llw ps sps lc palette


set output 'jaikkin_w.pdf'
set multiplot


#set ytics 0.2


set xrange[0.0:1.0]
set yrange[0.01:0.0]
set xlabel ' '
set label '|' at screen 0.01, 0.847 font ",10"
set label '|' at screen 0.01, 0.526 font ",10"
set label '|' at screen 0.01, 0.206 font ",10"
set ylabel 'w'
set xtics format ''
set ytics format "%3.3f"
set key bottom left font ",11" spacing 0.9 Right

set label 'Stage I' at 0.02,0.001 font ",16"
plot 'jaikkin_st1.dat'\
   ind 1 u 1:8:7 ev 3 tit 'P = 1304' w p ls 1 pt 1, '' ind 1 u 1:8:7 notit w l ls 1, '' ind 1 u 4:9:7 ev 3 notit w linesp ls 1 pt 1,\
'' ind 2 u 1:8:7 ev 3 tit '    2608' w p ls 1 pt 2, '' ind 2 u 1:8:7 notit w l ls 1, '' ind 2 u 4:9:7 ev 3 notit w linesp ls 1 pt 2,\
'' ind 3 u 1:8:7 ev 3 tit '    3912' w p ls 1 pt 3, '' ind 3 u 1:8:7 notit w l ls 1, '' ind 3 u 4:9:7 ev 3 notit w linesp ls 1 pt 3,\
'' ind 4 u 1:8:7 ev 3 tit '    5216' w p ls 1 pt 4, '' ind 4 u 1:8:7 notit w l ls 1, '' ind 4 u 4:9:7 ev 3 notit w linesp ls 1 pt 4,\
'' ind 5 u 1:8:7 ev 3 tit '    6520' w p ls 1 pt 5, '' ind 5 u 1:8:7 notit w l ls 1, '' ind 5 u 4:9:7 ev 3 notit w linesp ls 1 pt 5,\
'' ind 6 u 1:8:7 ev 3 tit '    7824' w p ls 1 pt 6, '' ind 6 u 1:8:7 notit w l ls 1, '' ind 6 u 4:9:7 ev 3 notit w linesp ls 1 pt 6,\
'' ind 7 u 1:8:7 ev 3 tit '    9128' w p ls 1 pt 5, '' ind 7 u 1:8:7 notit w l ls 1, '' ind 7 u 4:9:7 ev 3 notit w linesp ls 1 pt 5,\
'' ind 8 u 1:8:7 ev 3 tit '   10432' w p ls 1 pt 6, '' ind 8 u 1:8:7 notit w l ls 1, '' ind 8 u 4:9:7 ev 3 notit w linesp ls 1 pt 6,\
'' ind 9 u 1:8:7 ev 3 tit '   11736' w p ls 1 pt 7, '' ind 9 u 1:8:7 notit w l ls 1, '' ind 9 u 4:9:7 ev 3 notit w linesp ls 1 pt 7
unset label
set tmargin screen 0.67
set bmargin screen 0.38
set yrange[0.02:0.0]

set label 'Stage II' at 0.015,0.0025 font ",16"
plot 'jaikkin_st2.dat'\
   ind 0 u 1:8:7 ev 3 tit 'P = 13040' w p ls 1 pt 1, '' ind 0 u 1:8:7 notit w l ls 1, '' ind 0 u 4:9:7 ev 3 notit w linesp ls 1 pt 1,\
'' ind 1 u 1:8:7 ev 3 tit '    13700' w p ls 1 pt 2, '' ind 1 u 1:8:7 notit w l ls 1, '' ind 1 u 4:9:7 ev 3 notit w linesp ls 1 pt 2,\
'' ind 2 u 1:8:7 ev 3 tit '    14360' w p ls 1 pt 3, '' ind 2 u 1:8:7 notit w l ls 1, '' ind 2 u 4:9:7 ev 3 notit w linesp ls 1 pt 3,\
'' ind 3 u 1:8:7 ev 3 tit '    15020' w p ls 1 pt 4, '' ind 3 u 1:8:7 notit w l ls 1, '' ind 3 u 4:9:7 ev 3 notit w linesp ls 1 pt 4,\
'' ind 4 u 1:8:7 ev 3 tit '    15680' w p ls 1 pt 5, '' ind 4 u 1:8:7 notit w l ls 1, '' ind 4 u 4:9:7 ev 3 notit w linesp ls 1 pt 5,\
'' ind 5 u 1:8:7 ev 3 tit '    16340' w p ls 1 pt 6, '' ind 5 u 1:8:7 notit w l ls 1, '' ind 5 u 4:9:7 ev 3 notit w linesp ls 1 pt 6,\
'' ind 6 u 1:8:7 ev 3 tit '    17000' w p ls 1 pt 5, '' ind 6 u 1:8:7 notit w l ls 1, '' ind 6 u 4:9:7 ev 3 notit w linesp ls 1 pt 5,\
'' ind 7 u 1:8:7 ev 3 tit '    17660' w p ls 1 pt 6, '' ind 7 u 1:8:7 notit w l ls 1, '' ind 7 u 4:9:7 ev 3 notit w linesp ls 1 pt 6,\
'' ind 8 u 1:8:7 ev 3 tit '    18320' w p ls 1 pt 7, '' ind 8 u 1:8:7 notit w l ls 1, '' ind 8 u 4:9:7 ev 3 notit w linesp ls 1 pt 7,\
'' ind 9 u 1:8:7 ev 3 tit '    18980' w p ls 1 pt 8, '' ind 9 u 1:8:7 notit w l ls 1, '' ind 9 u 4:9:7 ev 3 notit w linesp ls 1 pt 8
unset label

set tmargin screen 0.35
set bmargin screen 0.06

set xlabel 'r' offset screen 0,0.0
set xtics format "%2.1f"
set yrange[0.05:0.0]

set label 'Stage III' at 0.01,0.005 font ",16"
plot 'jaikkin_st3.dat'\
   ind 0 u 1:14:13 ev 3 tit 'P = 19640' w p ls 1 pt 1, '' ind 0 u 1:14:13 notit w l ls 1, '' ind 0 u 4:15:13 ev 5 notit w linesp ls 1 pt 1, '' ind 0 u 7:16:13 ev 3 notit w linesp ls 1 pt 1,\
'' ind 1 u 1:14:13 ev 3 tit '    20640' w p ls 1 pt 2, '' ind 1 u 1:14:13 notit w l ls 1, '' ind 1 u 4:15:13 ev 5 notit w linesp ls 1 pt 2, '' ind 1 u 7:16:13 ev 3 notit w linesp ls 1 pt 2,\
'' ind 2 u 1:14:13 ev 3 tit '    21640' w p ls 1 pt 3, '' ind 2 u 1:14:13 notit w l ls 1, '' ind 2 u 4:15:13 ev 5 notit w linesp ls 1 pt 3, '' ind 2 u 7:16:13 ev 3 notit w linesp ls 1 pt 3,\
'' ind 3 u 1:14:13 ev 3 tit '    22640' w p ls 1 pt 4, '' ind 3 u 1:14:13 notit w l ls 1, '' ind 3 u 4:15:13 ev 5 notit w linesp ls 1 pt 4, '' ind 3 u 7:16:13 ev 3 notit w linesp ls 1 pt 4,\
'' ind 4 u 1:14:13 ev 3 tit '    23640' w p ls 1 pt 5, '' ind 4 u 1:14:13 notit w l ls 1, '' ind 4 u 4:15:13 ev 5 notit w linesp ls 1 pt 5, '' ind 4 u 7:16:13 ev 3 notit w linesp ls 1 pt 5,\
'' ind 5 u 1:14:13 ev 3 tit '    24640' w p ls 1 pt 6, '' ind 5 u 1:14:13 notit w l ls 1, '' ind 5 u 4:15:13 ev 5 notit w linesp ls 1 pt 6, '' ind 5 u 7:16:13 ev 3 notit w linesp ls 1 pt 6,\
'' ind 6 u 1:14:13 ev 3 tit '    25640' w p ls 1 pt 5, '' ind 6 u 1:14:13 notit w l ls 1, '' ind 6 u 4:15:13 ev 5 notit w linesp ls 1 pt 5, '' ind 6 u 7:16:13 ev 3 notit w linesp ls 1 pt 5,\
'' ind 7 u 1:14:13 ev 3 tit '    26640' w p ls 1 pt 6, '' ind 7 u 1:14:13 notit w l ls 1, '' ind 7 u 4:15:13 ev 5 notit w linesp ls 1 pt 6, '' ind 7 u 7:16:13 ev 3 notit w linesp ls 1 pt 6,\
'' ind 8 u 1:14:13 ev 3 tit '    27640' w p ls 1 pt 7, '' ind 8 u 1:14:13 notit w l ls 1, '' ind 8 u 4:15:13 ev 5 notit w linesp ls 1 pt 7, '' ind 8 u 7:16:13 ev 3 notit w linesp ls 1 pt 7,\
'' ind 9 u 1:14:13 ev 3 tit '    29640' w p ls 1 pt 8, '' ind 9 u 1:14:13 notit w l ls 1, '' ind 9 u 4:15:13 ev 5 notit w linesp ls 1 pt 8, '' ind 9 u 7:16:13 ev 3 notit w linesp ls 1 pt 8,\
'' ind 10 u 1:14:13 ev 3 tit '   29640' w p ls 1 pt 3, '' ind 10 u 1:14:13 notit w l ls 1, '' ind 10 u 4:15:13 ev 5 notit w linesp ls 1 pt 3, '' ind 10 u 7:16:13 ev 3 notit w linesp ls 1 pt 3,\
'' u 10:18 tit "η" w p pt 2 ps 0.7 lc -1

unset multiplot